<h1>Gestpay payment</h1>

{# Display cart summary here. `cart` is available in context. #}

<form action="{{ form.action }}" method="POST">
  {{ form.as_p }}
  <button>Proceed with payment</button>
</form>
